#
# spec file for package gokart
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gokart
Version:        0.5.1
Release:        bp155.1.7
Summary:        Static analysis tool for securing Go code
License:        Apache-2.0
URL:            https://github.com/praetorian-inc/gokart
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.19
Requires:       go >= 1.19
ExcludeArch:    s390
ExcludeArch:    %{ix86}
# Make sure that the binary is not getting stripped.
%{go_nostrip}

%description
GoKart is a static analysis tool for Go that finds vulnerabilities using the
SSA (single static assignment) form of Go source code. It is capable of tracing
the source of variables and function arguments to determine whether input
sources are safe, which reduces the number of false positives compared to
other Go security scanners. For instance, a SQL query that is concatenated
with a variable might traditionally be flagged as SQL injection; however,
GoKart can figure out if the variable is actually a constant or constant
equivalent, in which case there is no vulnerability.

%prep
%setup -qa1

%build
CGO_ENABLED=0
go build -mod=vendor -buildmode=pie

%install
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 gokart %{buildroot}%{_bindir}/gokart

%files
%license LICENSE
%doc README.md SECURITY.md
%{_bindir}/gokart

%changelog
* Mon Nov 28 2022 alexandre.vicenzi@suse.com
- Update to version 0.5.1:
  * Update dependencies (#80)
* Fri Feb  4 2022 alexandre.vicenzi@suse.com
- Update to version 0.4.0:
  * Update removal of bad packages from package list
  * Add version command to gokart
  * Fix incorrect use of closures
  * Emit JSON output only once
  * Improve error reporting
  * Added syscall CMDi sinks
* Fri Oct  8 2021 alexandre.vicenzi@suse.com
- Update to version 0.3.0:
  * Enhancements
  * Output findings to file CLI flag
  * Verbose output source parent function fix
  * Add exit code on findings flag
  * Update remote scanning functionality to include private repos
  * Add basic dockerfile and README
  * CWE mappings for findings
  * Output total findings information
  * Output findings as json
  * Highlight relevant finding lines
  * Bug Fixes
  * Channel incorrectly identified as source of untrusted input
  * Verbose trace has incorrect parent signatures
  * panic: err: go command required
  * panic: index out of range
* Thu Sep  2 2021 alexandre.vicenzi@suse.com
- Update to version 0.2.0:
  * Added support for writing findings output to a file to ease CI/CD integration via the -o flag.
  * Added remote fetch + scan functionality via the -r flag.
  * Updated README to cover new functionality.
* Thu Aug 19 2021 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial version
